==> Paws-0.32.tar.gz: Paws-0.32/lib/Paws/WorkDocs/DocumentSourceUrlMap.pm <==
package Paws::WorkDocs::DocumentSourceUrlMap;
  use Moose;
  with 'Paws::API::MapParser';

  use MooseX::ClassAttribute;
  class_has xml_keys =>(is => 'ro', default => 'key');
  class_has xml_values =>(is => 'ro', default => 'value');

  has ORIGINAL => (is => 'ro', isa => 'Str');
  has WITH_COMMENTS => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::WorkDocs::DocumentSourceUrlMap

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::WorkDocs::DocumentSourceUrlMap object:

  $service_obj->Method(Att1 => { ORIGINAL => $value, ..., WITH_COMMENTS => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::WorkDocs::DocumentSourceUrlMap object:

  $result = $service_obj->Method(...);
  $result->Att1->ORIGINAL

=head1 DESCRIPTION

This class has no description

=head1 ATTRIBUTES


=head2 ORIGINAL => Str


=head2 WITH_COMMENTS => Str



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::WorkDocs>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/WorkDocs/DocumentSourceUrlMap.pm <==
package Paws::WorkDocs::DocumentSourceUrlMap;
  use Moose;
  with 'Paws::API::MapParser';

  use MooseX::ClassAttribute;
  class_has xml_keys =>(is => 'ro', default => 'key');
  class_has xml_values =>(is => 'ro', default => 'value');

  has ORIGINAL => (is => 'ro', isa => 'Str');
  has WITH_COMMENTS => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::WorkDocs::DocumentSourceUrlMap

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::WorkDocs::DocumentSourceUrlMap object:

  $service_obj->Method(Att1 => { ORIGINAL => $value, ..., WITH_COMMENTS => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::WorkDocs::DocumentSourceUrlMap object:

  $result = $service_obj->Method(...);
  $result->Att1->ORIGINAL

=head1 DESCRIPTION

This class has no description

=head1 ATTRIBUTES


=head2 ORIGINAL => Str


=head2 WITH_COMMENTS => Str



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::WorkDocs>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
